<?php
/**
 * Plugin MySkinSelect
 *
 * @package	PLX
 * @version	1.0.2
 * @date	20/10/2011
 * @author 	Stephane F
 *
 * Utilisation:
 * Ajouter dans le fichier sidebar.php les lignes suivantes pour afficher le sélecteur de thèmes
 *
 *		<h3>Th&egrave;mes</h3>
 *		<?php $plxShow->callHook('MySkinSelect') ?>
 *
 **/
class plxMySkinSelect extends plxPlugin {

	public $aSkins = array(); # tableau contenant la liste des themes

	/**
	 * Constructeur de la classe
	 *
	 * @param	default_lang	langue par défaut utilisée par PluXml
	 * @return	null
	 * @author	Stephane F
	 **/
	public function __construct($default_lang) {

		# Appel du constructeur de la classe plxPlugin (obligatoire)
		parent::__construct($default_lang);

		# Autorisation d'acces à la configuration du plugin
		$this->setConfigProfil(PROFIL_ADMIN, PROFIL_MANAGER);

		# Déclarations des hooks
		$this->addHook('Index', 'Index');
		$this->addHook('IndexBegin', 'IndexBegin');
		$this->addHook('MySkinSelect', 'MySkinSelect');

	}

	/**
	 * Méthode qui préconfigure le plugin
	 *
	 * @return	stdio
	 * @author	Cyril MAGUIRE
	 **/
	public function onActivate() {
		#Paramètres par défaut
		if(!is_file($this->plug['parameters.xml'])) {
			$this->setParam('cookie', 'style', 'cdata');
			$this->saveParams();
		}
	}

	/**
	 * Méthode qui récupère la liste des thèmes dans le dossier /thèmes
	 *
	 * @author	Stephane F.
	 *
	 **/
	public function getSkins() {

		$files = plxGlob::getInstance(PLX_ROOT.'themes', true);
		if($styles = $files->query("/[a-z0-9-_\.\(\)]+/i")) {
			foreach($styles as $k=>$v) {
				if(substr($v,0,7) != 'mobile.')	$this->aSkins[$v] = $v;
			}
		}
	}

	/**
	 * Méthode qui applique le changement de thèmes
	 *
	 * @author	Stephane F., Cyril MAGUIRE
	 *
	 **/
	public function Index() {
		$plxMotor = plxMotor::getInstance();
		if(!empty($_POST['style'])) { # Si le formulaire est soumis
			//Si le thème choisi est le thème par défaut, on sélectionne le thème choisi par défaut par l'administeur
			if ($_POST['style'] == 'defaut') {
				$_POST['style'] = $plxMotor->style;
			}
			$_SESSION['referer'] = $_POST['referer'];
			setcookie(''.$this->getParam('cookie').'', $_POST['style'], time()+3600*24*2);
			header('Location: ./');
			exit;
		}

		echo '<?php $plxMotor->style = plxUtils::getValue($_COOKIE["'.$this->getParam('cookie').'"], $plxMotor->style); ?>';

	}

	/**
	 * Méthode qui renvoie vers la page à l'origine du changement de thème
	 *
	 * @author Cyril MAGUIRE
	 */
	public function IndexBegin(){
		if (isset($_SESSION['referer'])){
			header('Location:'.$_SESSION['referer']);
			unset($_SESSION['referer']);
			exit();
		}
	}

	/**
	 * Méthode qui affiche la liste déroulante de tous les thèmes disponibles
	 *
	 * @return	stdio
	 * @author	Stephane F., Cyril MAGUIRE
	 *
	 **/
	public function MySkinSelect() {
		# Récuperation de la liste des thèmes
		$this->getSkins();

		# Mise en place du sélecteur
		$plxMotor = plxMotor::getInstance();
		$current_skin = plxUtils::getValue($_COOKIE[".$this->getParam('style')."], $plxMotor->style);
		echo '<form action="'.$plxMotor->urlRewrite().'" method="post">';
		plxUtils::printSelect('style', $this->aSkins, $current_skin);
		echo '<input type="hidden" name="referer" value="'.$plxMotor->urlRewrite(plxUtils::getGets()).'"/>';
		echo '<input type="submit" value="ok"/>';
		echo '</form>';

	}
}
?>